==> japhar-0.04.tar.gz: japhar-0.04/lib/libnative/sun.awt.motif/common.c <==
/* -*- Mode: C; c-file-style: "gnu" -*-
   common.c -- common methods for the awt cruft.
   Created: Chris Toshok <toshok@hungry.com>, 9-Mar-1998.
 */
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1998 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */

#include "jni.h"
#include "native-threads.h"
#include "ClazzFile.h"
#include "log.h"
#include <Xm/Xm.h>
#include <assert.h>

#include "common.h"

#define MYLOG "Native"

XtAppContext _awt_appContext;
Widget _awt_toplevelWidget;
Display *_awt_Display;
Screen *_awt_Screen;

HMonitor _awt_Monitor;

void
initialize_awt()
{
  static jboolean initialized = JNI_FALSE;
  int argc_fake = 0;
  JAVARLOG0(MYLOG, 1, "sun.awt.motif/initialize_awt() start\n");

  /* race condition here... hope everything's going to be ok. */
  if (!initialized)
    {
      initialized = JNI_TRUE;

#ifndef THREAD_SAFE_MOTIF
      _awt_Monitor = MONITOR_createNamed("awt-lock");
#endif

      LOCK_AWT();

      _awt_toplevelWidget  = XtAppInitialize(&_awt_appContext,
					     "AWTapp",
					     NULL, 0, &argc_fake, NULL, NULL, NULL, 0);
      _awt_Display = XtDisplay(_awt_toplevelWidget);
      _awt_Screen = XtScreen(_awt_toplevelWidget);

      UNLOCK_AWT();
    }
}

Widget
get_component_widget(JNIEnv *env,
		     jobject component_peer)
{
  jclass component_class = (*env)->FindClass(env, "sun/awt/motif/MComponentPeer");
  jfieldID pData = (*env)->GetFieldID(env, component_class, "pData", "I");

  assert(sizeof(jint) >= sizeof(Widget));

  return (Widget)(*env)->GetIntField(env, component_peer, pData);
}

void
set_component_widget(JNIEnv *env,
		     jobject component_peer,
		     Widget widget)
{
  jclass component_class = (*env)->FindClass(env, "sun/awt/motif/MComponentPeer");
  jfieldID pData = (*env)->GetFieldID(env, component_class, "pData", "I");

  if (NULL == pData) {
    JAVARLOG1(MYLOG, 1, "no jint field %s.pData\n",
	      ((ClazzFile*)component_class)->class_name);
  }

  assert(NULL != component_class);
  assert(NULL != pData);
  assert(sizeof(jint) >= sizeof(Widget));

  (*env)->SetIntField(env, component_peer, pData, (jint)widget);
}

Widget
get_menubar_widget(JNIEnv *env,
		   jobject menubar_peer)
{
  jclass menubar_class = (*env)->GetObjectClass(env, menubar_peer);
  jfieldID pData = (*env)->GetFieldID(env, menubar_class, "pData", "I");

  assert(sizeof(jint) >= sizeof(Widget));

  return (Widget)(*env)->GetIntField(env, menubar_peer, pData);
}

void
set_menubar_widget(JNIEnv *env,
		   jobject menubar_peer,
		   Widget widget)
{
  jclass menubar_class = (*env)->GetObjectClass(env, menubar_peer);
  jfieldID pData = (*env)->GetFieldID(env, menubar_class, "pData", "I");

  (*env)->SetIntField(env, menubar_peer, pData, (jint)widget);
}

Widget
get_menuitem_widget(JNIEnv *env,
		    jobject menuitem_peer)
{
  jclass menuitem_class = (*env)->FindClass(env, "sun/awt/motif/MMenuItemPeer");
  jfieldID pData = (*env)->GetFieldID(env, menuitem_class, "pData", "I");

  assert(sizeof(jint) >= sizeof(Widget));

  return (Widget)(*env)->GetIntField(env, menuitem_peer, pData);
}

void
set_menuitem_widget(JNIEnv *env,
		    jobject menuitem_peer,
		    Widget widget)
{
  jclass menuitem_class = (*env)->FindClass(env, "sun/awt/motif/MMenuItemPeer");
  jfieldID pData = (*env)->GetFieldID(env, menuitem_class, "pData", "I");
  
  assert(sizeof(jint) >= sizeof(Widget));

  (*env)->SetIntField(env, menuitem_peer, pData, (jint)widget);
}

char *
get_menuitem_label(JNIEnv *env,
		   jobject menuitem_peer)
{
  jclass peer_class, menuitem_class;
  jfieldID target_field;
  jobject target;
  jfieldID label_field;
  jstring label;
  const jbyte *label_bytes;
  char *ret_val;

  peer_class = (*env)->FindClass(env, "sun/awt/motif/MMenuItemPeer");
  menuitem_class = (*env)->FindClass(env, "java/awt/MenuItem");

  target_field = (*env)->GetFieldID(env, peer_class, "target", "Ljava/awt/MenuItem;");
  label_field = (*env)->GetFieldID(env, menuitem_class, "label", "Ljava/lang/String;");

  target = (*env)->GetObjectField(env, menuitem_peer, target_field);
  label = (*env)->GetObjectField(env, target, label_field);

  label_bytes = (*env)->GetStringUTFChars(env, label, NULL);

  ret_val = strdup((const char*)label_bytes);

  (*env)->ReleaseStringUTFChars(env, label, label_bytes);

  return ret_val;
}

==> japhar-0.05.tar.gz: japhar-0.05/lib/libnative/sun.awt.motif/common.c <==
/* -*- Mode: C; c-file-style: "gnu" -*-
   common.c -- common methods for the awt cruft.
   Created: Chris Toshok <toshok@hungry.com>, 9-Mar-1998.
 */
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1998 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */

#include "jni.h"
#include "native-threads.h"
#include "ClazzFile.h"
#include "log.h"
#include <Xm/Xm.h>
#include <assert.h>

#include "common.h"

#define MYLOG "Native"

XtAppContext _awt_appContext;
Widget _awt_toplevelWidget;
Display *_awt_Display;
Screen *_awt_Screen;

HMonitor _awt_Monitor;

void
initialize_awt()
{
  static jboolean initialized = JNI_FALSE;
  int argc_fake = 0;
  JAVARLOG0(MYLOG, 1, "sun.awt.motif/initialize_awt() start\n");

  /* race condition here... hope everything's going to be ok. */
  if (!initialized)
    {
      initialized = JNI_TRUE;

#ifndef THREAD_SAFE_MOTIF
      _awt_Monitor = MONITOR_create();
#endif

      LOCK_AWT();

      _awt_toplevelWidget  = XtAppInitialize(&_awt_appContext,
					     "AWTapp",
					     NULL, 0, &argc_fake, NULL, NULL, NULL, 0);
      _awt_Display = XtDisplay(_awt_toplevelWidget);
      _awt_Screen = XtScreen(_awt_toplevelWidget);

      UNLOCK_AWT();
    }
}

Widget
get_component_widget(JNIEnv *env,
		     jobject component_peer)
{
  jclass component_class = (*env)->FindClass(env, "sun/awt/motif/MComponentPeer");
  jfieldID pData = (*env)->GetFieldID(env, component_class, "pData", "I");

  assert(sizeof(jint) >= sizeof(Widget));

  return (Widget)(*env)->GetIntField(env, component_peer, pData);
}

void
set_component_widget(JNIEnv *env,
		     jobject component_peer,
		     Widget widget)
{
  jclass component_class = (*env)->FindClass(env, "sun/awt/motif/MComponentPeer");
  jfieldID pData = (*env)->GetFieldID(env, component_class, "pData", "I");

  if (NULL == pData) {
    JAVARLOG1(MYLOG, 1, "no jint field %s.pData\n",
	      ((ClazzFile*)component_class)->class_name);
  }

  assert(NULL != component_class);
  assert(NULL != pData);
  assert(sizeof(jint) >= sizeof(Widget));

  (*env)->SetIntField(env, component_peer, pData, (jint)widget);
}

Widget
get_menubar_widget(JNIEnv *env,
		   jobject menubar_peer)
{
  jclass menubar_class = (*env)->GetObjectClass(env, menubar_peer);
  jfieldID pData = (*env)->GetFieldID(env, menubar_class, "pData", "I");

  assert(sizeof(jint) >= sizeof(Widget));

  return (Widget)(*env)->GetIntField(env, menubar_peer, pData);
}

void
set_menubar_widget(JNIEnv *env,
		   jobject menubar_peer,
		   Widget widget)
{
  jclass menubar_class = (*env)->GetObjectClass(env, menubar_peer);
  jfieldID pData = (*env)->GetFieldID(env, menubar_class, "pData", "I");

  (*env)->SetIntField(env, menubar_peer, pData, (jint)widget);
}

Widget
get_menuitem_widget(JNIEnv *env,
		    jobject menuitem_peer)
{
  jclass menuitem_class = (*env)->FindClass(env, "sun/awt/motif/MMenuItemPeer");
  jfieldID pData = (*env)->GetFieldID(env, menuitem_class, "pData", "I");

  assert(sizeof(jint) >= sizeof(Widget));

  return (Widget)(*env)->GetIntField(env, menuitem_peer, pData);
}

void
set_menuitem_widget(JNIEnv *env,
		    jobject menuitem_peer,
		    Widget widget)
{
  jclass menuitem_class = (*env)->FindClass(env, "sun/awt/motif/MMenuItemPeer");
  jfieldID pData = (*env)->GetFieldID(env, menuitem_class, "pData", "I");
  
  assert(sizeof(jint) >= sizeof(Widget));

  (*env)->SetIntField(env, menuitem_peer, pData, (jint)widget);
}

char *
get_menuitem_label(JNIEnv *env,
		   jobject menuitem_peer)
{
  jclass peer_class, menuitem_class;
  jfieldID target_field;
  jobject target;
  jfieldID label_field;
  jstring label;
  const jbyte *label_bytes;
  char *ret_val;

  peer_class = (*env)->FindClass(env, "sun/awt/motif/MMenuItemPeer");
  menuitem_class = (*env)->FindClass(env, "java/awt/MenuItem");

  target_field = (*env)->GetFieldID(env, peer_class, "target", "Ljava/awt/MenuItem;");
  label_field = (*env)->GetFieldID(env, menuitem_class, "label", "Ljava/lang/String;");

  target = (*env)->GetObjectField(env, menuitem_peer, target_field);
  label = (*env)->GetObjectField(env, target, label_field);

  label_bytes = (*env)->GetStringUTFChars(env, label, NULL);

  ret_val = strdup((const char*)label_bytes);

  (*env)->ReleaseStringUTFChars(env, label, label_bytes);

  return ret_val;
}
